@@ -15,7 +15,7 @@ echo $(hostname):$PORT $REDIS_PASSWORD > ~/.ray-test-72363726-details
 
 GIGABYTE=1000000000  # close enough
 
-ray start --head --redis-port=$PORT --redis-password=$REDIS_PASSWORD --memory $GIGABYTE --object-store-memory $GIGABYTE --redis-max-memory $GIGABYTE
+ray start --head --port=$PORT --redis-password=$REDIS_PASSWORD --memory $GIGABYTE --object-store-memory $GIGABYTE --redis-max-memory $GIGABYTE
 
 # in order to find both the uninstalled paramsurvey and our test program,
 # which ray needs to pickle, the PYTHONPATH must be manipulated. See
@@ -24,5 +24,8 @@ ray start --head --redis-port=$PORT --redis-password=$REDIS_PASSWORD --memory $G
 RAY_HEAD_FILE=~/.ray-test-72363726-details PARAMSURVEY_BACKEND=ray pytest $COVERAGE $1
 RAY_LOCAL_MODE=1 RAY_HEAD_FILE=~/.ray-test-72363726-details PARAMSURVEY_BACKEND=ray pytest $COVERAGE $PYTEST_STDERR_VISIBLE $1
 
+RAY_HEAD_FILE=~/.ray-test-72363726-details PARAMSURVEY_BACKEND=ray pytest $COVERAGE $1/test-generic_init_max_tasks_per_child.py
+# do not test max_tasks with local mode
+
 ray stop
 
